Barcode2DMatrix class

Matrix representing the raw code pixels

Constructors

Barcode2DMatrix(int width, int height, double ratio, Iterable<bool> pixels)
Create a 2d barcode matrix
const
Barcode2DMatrix.fromXY(int width, int height, double ratio, bool isDark(int x, int y))
Create a 2d barcode matrix from a function callback
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the matrix
final
pixels → Iterable<bool>
The pixels of the matrix
final
ratio → double
The pixel ratio (width/height)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
The width of the matrix
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited