BarcodeDataMatrix class

Data Matrix

A Data Matrix is a two-dimensional barcode consisting of black and white "cells" or modules arranged in either a square or rectangular pattern, also known as a matrix.

Inheritance

Constructors

BarcodeDataMatrix()
Create a BarcodeDataMatrix object
const

Properties

charSet → Iterable<int>
Returns the list of accepted codePoints for this CodeType
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
maxLength → int
Returns maximum number of characters this CodeType can encode
no setteroverride
minLength → int
Returns minimum number of characters this CodeType can encode
no setterinherited
name → String
Returns the name of this CodeType
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(Uint8List data) → Barcode2DMatrix
Actual barcode computation method, returns a matrix of bool which represents the presence or absence of a pixel
override
isValid(String data) → bool
Check if the Barcode is valid
inherited
isValidBytes(Uint8List data) → bool
Check if the Barcode is valid
inherited
make(String data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) → Iterable<BarcodeElement>
Main method to produce the barcode graphic description. Returns a stream of drawing operations required to properly display the barcode as a UTF-8 string.
override
makeBytes(Uint8List data, {required double width, required double height, bool drawText = false, double? fontHeight, double? textPadding}) → Iterable<BarcodeElement>
Generate the barcode graphic description like make but takes a Uint8List data.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHex(String data) → String
Computes a hexadecimal representation of the barcode, mostly for testing purposes
inherited
toString() → String
A string representation of this object.
inherited
toSvg(String data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = 'monospace', double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) → String
Create an SVG file with this Barcode from String data
inherited
toSvgBytes(Uint8List data, {double x = 0, double y = 0, double width = 200, double height = 80, bool drawText = true, String fontFamily = 'monospace', double? fontHeight, double? textPadding, int color = 0x000000, bool fullSvg = true, double baseline = .75}) → String
Create an SVG file with this Barcode from Uint8List data
inherited
verify(String data) → void
Check if the Barcode is valid. Throws BarcodeException with a proper message in case of error
inherited
verifyBytes(Uint8List data) → void
Check if the Barcode is valid. Throws BarcodeException with a proper message in case of error
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited