GFPoly class

Constructors

GFPoly(GaloisField gf, List<int> coefficients)
GFPoly.monominalPoly(GaloisField field, int degree, int coeff)
factory

Properties

coefficients ↔ List<int>
getter/setter pair
gf ↔ GaloisField
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOrSubstract(GFPoly other) → GFPoly
divide(GFPoly other) → List<GFPoly>
getCoefficient(int degree) → int
getDegree() → int
multByMonominal(int degree, int coeff) → GFPoly
multiply(GFPoly other) → GFPoly
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
zero() → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited