ReedSolomonEncoder class

Constructors

ReedSolomonEncoder(GaloisField gf)

Properties

gf ↔ GaloisField
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
polynomes ↔ List<GFPoly>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode(List<int> data, int eccCount) → List<int>
getPolynomial(int degree) → GFPoly
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited