QREmbeddedImageException class

An exception that is thrown when something goes wrong with the ImageProvider for the embedded image of a QrImageView or QrPainter.

Implemented types

Constructors

QREmbeddedImageException(String message)
Create a new QrEmbeddedImageException.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A message describing the exception state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited