QRUnsupportedVersionException class

An exception that is thrown when an invalid QR code version / type is requested.

Implemented types

Constructors

QRUnsupportedVersionException(int providedVersion)
Create a new QrUnsupportedVersionException.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A message describing the exception state.
final
providedVersion → int
The version you passed to the QR code operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited