PaintCache class

Caches painter objects so we do have to recreate them and waste expensive cycles.

Constructors

PaintCache()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cache(Paint paint, QRCodeElement element, {FinderPatternPosition? position}) → void
Save a Paint for the provided element and position into the cache.
firstPaint(QRCodeElement element, {FinderPatternPosition? position}) → Paint?
Retrieve the first Paint object from the paint cache for the provided element and position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paints(QRCodeElement element, {FinderPatternPosition? position}) → List<Paint?>
Retrieve all Paint objects from the paint cache for the provided element and position. Note: Finder pattern elements can only have a max one Paint object per position. As such they will always return a List with a fixed size of 1.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited